﻿using System;
using System.Collections.Generic;
using System.Text;
using System.Diagnostics;

using EA;
using WorkflowService.Model.EntityClasses;
using WorkflowService.Model.HelperClasses;
using WorkflowService.Model.DatabaseSpecific;


namespace EaWorkflowDesignerAddin.Ui
{
    public class MainformPresenter
    {
        private MainForm _view = new MainForm();
        private DataAccessAdapter _adapter = new DataAccessAdapter();


        public void ShowView(Repository repository)
        {
            if (_view == null || _view.IsDisposed)
            {
                _view = new MainForm();
            }

            _view.Presenter = new MainformPresenter();
            _view.Repository = repository;
            _view.ShowDialog();
        }

        public void GenerateWorkflowFromDiagram(
            string databaseServerName,
            string databaseName,
            Diagram stateMachineDiagram, 
            Repository repository)
        {
            if (stateMachineDiagram.Type != "Statechart")
            {
                _view.ShowError("Can only generate a workflow from a Statechart");
            }
            StateMachineEntity stateMachineEntity = new StateMachineEntity();
            stateMachineEntity.Name = stateMachineDiagram.Name;

            foreach (DiagramObject diagramObject in stateMachineDiagram.DiagramObjects)
            {
                Element element = repository.GetElementByID(diagramObject.ElementID);
                Debug.Print("{0}: {1}", element.Name, element.Type);
                if (element.Type == "State" || element.Type == "StateNode")
                {
                    StateEntity state = new StateEntity();
                    state.Name = element.Name;
                    stateMachineEntity.State.Add(state);
                }
            }

            // now save the object graph to the database:
            try
            {
                _adapter.ConnectionString = String.Format("data source={0};initial catalog={1};integrated security=SSPI;persist security info=False;packet size=4096",
                    databaseServerName, databaseName);

                _adapter.SaveEntity(stateMachineEntity);
            }
            catch (Exception ex)
            {
                _view.ShowError(ex.Message);
            }
        }

    }
}
